starcluster.commands.createimage.CmdCreateImage

Package starcluster :: Package commands :: Module createimage :: Class CmdCreateImage |
[hide private]
[frames] | no frames]

# Class CmdCreateImage

source code

    createimage [options] <instance-id> <image_name> <bucket>

    Create a new instance-store image (AMI) from a running EC2 instance

    Example:

        $ starcluster createimage i-999999 my-new-image mybucket

    NOTE: It is recommended not to create a new StarCluster AMI from
    an instance launched by StarCluster. Rather, launch a single
    StarCluster instance using ElasticFox or the EC2 API tools, modify
    it to your liking, and then use this command to create a new AMI from
    the running instance.

Instance Methods | [hide private]
addopts(self, parser) | source code
cancel_command(self, signum, frame) Exits program with return value of 1 | source code
execute(self, args) | source code
Inherited from `completers.InstanceCompleter` (private): `_completer` Inherited from `completers.Completer` (private): `_prep_for_completion` Inherited from `base.CmdBase`: `catch_ctrl_c`, `warn_experimental` Inherited from `optcomplete.CmdComplete`: `autocomplete`

Class Variables | [hide private]
| names = ``[``'``createimage``'``,` `'``ci``'``]``
| show_dns_names = `True`
| bucket = `None` hash(x)
| image_name = `None` hash(x)
Inherited from `completers.Completer` (private): `_cfg` Inherited from `base.CmdBase`: `gopts`, `gparser`, `opts`, `parser`, `subcmds_map` Inherited from `base.CmdBase` (private): `_cm`, `_ec2`, `_nm`, `_s3`

Properties | [hide private]
Inherited from `completers.Completer`: `completer` Inherited from `base.CmdBase`: `cfg`, `cluster_manager`, `cm`, `comp_words`, `ec2`, `goptions_dict`, `log`, `nm`, `node_manager`, `options_dict`, `s3`, `specified_options_dict`

Method Details | [hide private]

### addopts(self, parser) | source code
Overrides: base.CmdBase.addopts

### cancel_command(self, signum, frame) | source code
Exits program with return value of 1 Overrides: base.CmdBase.cancel_command (inherited documentation)